import { nextTick } from "vue";
import { createI18n } from "vue-i18n";
import en from "./locale/en.yaml";

export const supportedLocales = ["en", "en-PR"];
export const i18n = createI18n({
	legacy: false,
	locale: "en",
	messages: {
		en: en,
	},
});

export function setLanguage(locale: string) {
	// @ts-ignore
	i18n.global.locale.value = locale;
	document.querySelector("html")!.setAttribute("lang", locale);
}

export async function loadLocale(locale: string) {
	// Check if the locale is already loaded. If not, return
	// @ts-ignore
	if (i18n.global.availableLocales.indexOf(locale) !== -1) return;

	if (supportedLocales.indexOf(locale) === -1) throw `${locale} is not a valid locale`;

	const messages = await locales[locale as keyof typeof locales]();
	i18n.global.setLocaleMessage(locale, messages.default);

	return nextTick();
}

const locales = {
	"en-PR": () => import("./locale/en.pirate.yaml"),
};
